#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QDate>
#include <QAction>
#include <QMenuBar>
#include "mainwindow.h"

#define GESTURE_MIN_DISTANCE 50

MainWindow::MainWindow(QWidget *parent)
        : QWidget(parent)
{
        pressXPosition = 0;
        setAttribute(Qt::WA_Maemo5StackedWindow);

        QVBoxLayout *vBox = new QVBoxLayout(this);

        dateLabel = new QLabel("");
        vBox->addWidget(dateLabel, 0, Qt::AlignCenter);

        QHBoxLayout *hBox = new QHBoxLayout();
        vBox->addLayout(hBox, 1);

        graph = new ExpensesGraph();
        hBox->addWidget(graph, 1);

        QVBoxLayout *form = new QVBoxLayout();
        hBox->addLayout(form, 0);

        form->addStretch(2);

        form->addWidget(new QLabel(tr("Budget")), 0);
        budgetLabel = new QLabel("");
        form->addWidget(budgetLabel, 0, Qt::AlignRight | Qt::AlignVCenter);

        form->addWidget(new QLabel(tr("Expenses")), 0);
        totalLabel = new QLabel("");
        form->addWidget(totalLabel, 0, Qt::AlignRight | Qt::AlignVCenter);

        form->addWidget(new QLabel(tr("Difference")), 0);
        savedLabel = new QLabel("");
        form->addWidget(savedLabel, 0, Qt::AlignRight | Qt::AlignVCenter);

        form->addStretch(2);

        QPushButton *button2 = new QPushButton(tr("Add expense"));
        form->addWidget(button2, 1);
        connect (button2, SIGNAL(clicked()), this, SIGNAL(addExpenseSelected()));

        QMenuBar *menubar = new QMenuBar(this);
        menubar->addAction(tr("Budget"), this, SIGNAL(budgetSelected()));
        menubar->addAction(tr("Items"), this, SIGNAL(conceptsSelected()));
        menubar->addAction(tr("Expenses"), this, SIGNAL(expensesSelected()));
        menubar->addAction(tr("Scheduled"), this, SIGNAL(scheduledSelected()));
        menubar->addAction(tr("Summary"), this, SIGNAL(summarySelected()));
}

QSize MainWindow::minimumSizeHint() const
{
        return QSize(800, 454);
}

QSize MainWindow::sizeHint() const
{
        return QSize(800, 454);
}

void MainWindow::setMonthData(MonthData *data)
{
        month = data;
        /* set data to the graph as well */
        graph->setMonthData(data);
        connect(month, SIGNAL(expensesChanged()), this, SLOT(expensesChanged()));
        connect(month, SIGNAL(budgetChanged()), this, SLOT(budgetChanged()));

        updateAll();
}

void MainWindow::expensesChanged()
{
        updateTotalLabel();
        updateSavedLabel();
        updateGraph();
}

void MainWindow::budgetChanged()
{
        updateBudgetLabel();
        updateSavedLabel();
        updateGraph();
}

void MainWindow::updateAll()
{
        updateDateLabel();
        updateBudgetLabel();
        updateTotalLabel();
        updateSavedLabel();
        updateGraph();
}

void MainWindow::updateDateLabel()
{
        QString label = QString("<b>%1 %2</b>").arg(QDate::longMonthName(month->month())).arg(month->year());
        if (graph->accumulated()) {
                label.append(QString("   (%1)").arg(tr("accumulated view")));
        } else {
                label.append(QString("   (%1)").arg(tr("daily view")));
        }
        dateLabel->setText(label);
}

void MainWindow::updateBudgetLabel()
{
        budgetLabel->setNum(month->budget());
}

void MainWindow::updateTotalLabel()
{
        totalLabel->setNum(month->totalExpense());
}

void MainWindow::updateSavedLabel()
{
        double diff;

        diff = month->budget() - month->totalExpense();

        if (diff >= 0) {
                savedLabel->setText(QString("<font color='green'><b>+%1</b></font>").arg(diff));
        } else {
                savedLabel->setText(QString("<font color='red'><b>%1</b></font>").arg(diff));
        }
}

void MainWindow::updateGraph()
{
        graph->repaint();
}

void MainWindow::mousePressEvent(QMouseEvent *event)
{
        pressXPosition = event->x();
}

void MainWindow::mouseReleaseEvent(QMouseEvent *event)
{
        if (qAbs(event->x() - pressXPosition) > GESTURE_MIN_DISTANCE) {
                if (event->x() > pressXPosition) {
                        emit previousMonth();
                } else {
                        emit nextMonth();
                }
        } else {
                graph->changeView();
                updateDateLabel();
        }
}
